Introduction
============

.. include:: ../../../includes/global.rst

The ``debops.apache`` role allows you to setup and manage the `Apache HTTP Server`_
with version 2.4 and above.


Installation
~~~~~~~~~~~~

This role requires at least Ansible ``v2.1.5``. To install it, run:

.. code-block:: shell

   ansible-galaxy install debops.apache

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
